#[non_exhaustive]pub struct AssociateKmsKeyInput {
pub log_group_name: Option<String>,
pub kms_key_id: Option<String>,
pub resource_identifier: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_group_name: Option<String>The name of the log group.
In your AssociateKmsKey operation, you must specify either the resourceIdentifier parameter or the logGroup parameter, but you can't specify both.
kms_key_id: Option<String>The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data. This must be a symmetric KMS key. For more information, see Amazon Resource Names and Using Symmetric and Asymmetric Keys.
resource_identifier: Option<String>Specifies the target for this operation. You must specify one of the following:
-
Specify the following ARN to have future GetQueryResults operations in this account encrypt the results with the specified KMS key. Replace REGION and ACCOUNT_ID with your Region and account ID.
arn:aws:logs:REGION:ACCOUNT_ID:query-result:* -
Specify the ARN of a log group to have CloudWatch Logs use the KMS key to encrypt log events that are ingested and stored by that log group. The log group ARN must be in the following format. Replace REGION and ACCOUNT_ID with your Region and account ID.
arn:aws:logs:REGION:ACCOUNT_ID:log-group:LOG_GROUP_NAME
In your AssociateKmsKey operation, you must specify either the resourceIdentifier parameter or the logGroup parameter, but you can't specify both.
Implementations
Sourceimpl AssociateKmsKeyInput
impl AssociateKmsKeyInput
Sourcepub fn log_group_name(&self) -> Option<&str>
pub fn log_group_name(&self) -> Option<&str>
The name of the log group.
In your AssociateKmsKey operation, you must specify either the resourceIdentifier parameter or the logGroup parameter, but you can't specify both.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data. This must be a symmetric KMS key. For more information, see Amazon Resource Names and Using Symmetric and Asymmetric Keys.
Sourcepub fn resource_identifier(&self) -> Option<&str>
pub fn resource_identifier(&self) -> Option<&str>
Specifies the target for this operation. You must specify one of the following:
-
Specify the following ARN to have future GetQueryResults operations in this account encrypt the results with the specified KMS key. Replace REGION and ACCOUNT_ID with your Region and account ID.
arn:aws:logs:REGION:ACCOUNT_ID:query-result:* -
Specify the ARN of a log group to have CloudWatch Logs use the KMS key to encrypt log events that are ingested and stored by that log group. The log group ARN must be in the following format. Replace REGION and ACCOUNT_ID with your Region and account ID.
arn:aws:logs:REGION:ACCOUNT_ID:log-group:LOG_GROUP_NAME
In your AssociateKmsKey operation, you must specify either the resourceIdentifier parameter or the logGroup parameter, but you can't specify both.
Sourceimpl AssociateKmsKeyInput
impl AssociateKmsKeyInput
Sourcepub fn builder() -> AssociateKmsKeyInputBuilder
pub fn builder() -> AssociateKmsKeyInputBuilder
Creates a new builder-style object to manufacture AssociateKmsKeyInput.