#[non_exhaustive]pub struct CreateDeliveryInput {
pub delivery_source_name: Option<String>,
pub delivery_destination_arn: Option<String>,
pub record_fields: Option<Vec<String>>,
pub field_delimiter: Option<String>,
pub s3_delivery_configuration: Option<S3DeliveryConfiguration>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delivery_source_name: Option<String>The name of the delivery source to use for this delivery.
delivery_destination_arn: Option<String>The ARN of the delivery destination to use for this delivery.
record_fields: Option<Vec<String>>The list of record fields to be delivered to the destination, in order. If the delivery's log source has mandatory fields, they must be included in this list.
field_delimiter: Option<String>The field delimiter to use between record fields when the final output format of a delivery is in Plain, W3C, or Raw format.
s3_delivery_configuration: Option<S3DeliveryConfiguration>This structure contains parameters that are valid only when the delivery's delivery destination is an S3 bucket.
An optional list of key-value pairs to associate with the resource.
For more information about tagging, see Tagging Amazon Web Services resources
Implementations
Sourceimpl CreateDeliveryInput
impl CreateDeliveryInput
Sourcepub fn delivery_source_name(&self) -> Option<&str>
pub fn delivery_source_name(&self) -> Option<&str>
The name of the delivery source to use for this delivery.
Sourcepub fn delivery_destination_arn(&self) -> Option<&str>
pub fn delivery_destination_arn(&self) -> Option<&str>
The ARN of the delivery destination to use for this delivery.
Sourcepub fn record_fields(&self) -> &[String]
pub fn record_fields(&self) -> &[String]
The list of record fields to be delivered to the destination, in order. If the delivery's log source has mandatory fields, they must be included in this list.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .record_fields.is_none().
Sourcepub fn field_delimiter(&self) -> Option<&str>
pub fn field_delimiter(&self) -> Option<&str>
The field delimiter to use between record fields when the final output format of a delivery is in Plain, W3C, or Raw format.
Sourcepub fn s3_delivery_configuration(&self) -> Option<&S3DeliveryConfiguration>
pub fn s3_delivery_configuration(&self) -> Option<&S3DeliveryConfiguration>
This structure contains parameters that are valid only when the delivery's delivery destination is an S3 bucket.
An optional list of key-value pairs to associate with the resource.
For more information about tagging, see Tagging Amazon Web Services resources
Sourceimpl CreateDeliveryInput
impl CreateDeliveryInput
Sourcepub fn builder() -> CreateDeliveryInputBuilder
pub fn builder() -> CreateDeliveryInputBuilder
Creates a new builder-style object to manufacture CreateDeliveryInput.