CreateImportTaskFluentBuilder

Struct CreateImportTaskFluentBuilder 

pub struct CreateImportTaskFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateImportTask.

Starts an import from a data source to CloudWatch Log and creates a managed log group as the destination for the imported data. Currently, CloudTrail Event Data Store is the only supported data source.

The import task must satisfy the following constraints:

  • The specified source must be in an ACTIVE state.

  • The API caller must have permissions to access the data in the provided source and to perform iam:PassRole on the provided import role which has the same permissions, as described below.

  • The provided IAM role must trust the "cloudtrail.amazonaws.com" principal and have the following permissions:

    • cloudtrail:GetEventDataStoreData

    • logs:CreateLogGroup

    • logs:CreateLogStream

    • logs:PutResourcePolicy

    • (If source has an associated Amazon Web Services KMS Key) kms:Decrypt

    • (If source has an associated Amazon Web Services KMS Key) kms:GenerateDataKey

    Example IAM policy for provided import role:

    \[ { "Effect": "Allow", "Action": "iam:PassRole", "Resource": "arn:aws:iam::123456789012:role/apiCallerCredentials", "Condition": { "StringLike": { "iam:AssociatedResourceARN": "arn:aws:logs:us-east-1:123456789012:log-group:aws/cloudtrail/f1d45bff-d0e3-4868-b5d9-2eb678aa32fb:*" } } }, { "Effect": "Allow", "Action": \[ "cloudtrail:GetEventDataStoreData" \], "Resource": \[ "arn:aws:cloudtrail:us-east-1:123456789012:eventdatastore/f1d45bff-d0e3-4868-b5d9-2eb678aa32fb" \] }, { "Effect": "Allow", "Action": \[ "logs:CreateImportTask", "logs:CreateLogGroup", "logs:CreateLogStream", "logs:PutResourcePolicy" \], "Resource": \[ "arn:aws:logs:us-east-1:123456789012:log-group:/aws/cloudtrail/*" \] }, { "Effect": "Allow", "Action": \[ "kms:Decrypt", "kms:GenerateDataKey" \], "Resource": \[ "arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012" \] } \]

  • If the import source has a customer managed key, the "cloudtrail.amazonaws.com" principal needs permissions to perform kms:Decrypt and kms:GenerateDataKey.

  • There can be no more than 3 active imports per account at a given time.

  • The startEventTime must be less than or equal to endEventTime.

  • The data being imported must be within the specified source's retention period.

Implementations

Source

impl CreateImportTaskFluentBuilder

pub fn as_input(&self) -> &CreateImportTaskInputBuilder

Access the CreateImportTask as a reference.

pub async fn send( self, ) -> Result<CreateImportTaskOutput, SdkError<CreateImportTaskError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateImportTaskOutput, CreateImportTaskError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn import_source_arn(self, input: impl Into<String>) -> Self

The ARN of the source to import from.

pub fn set_import_source_arn(self, input: Option<String>) -> Self

The ARN of the source to import from.

pub fn get_import_source_arn(&self) -> &Option<String>

The ARN of the source to import from.

pub fn import_role_arn(self, input: impl Into<String>) -> Self

The ARN of the IAM role that grants CloudWatch Logs permission to import from the CloudTrail Lake Event Data Store.

pub fn set_import_role_arn(self, input: Option<String>) -> Self

The ARN of the IAM role that grants CloudWatch Logs permission to import from the CloudTrail Lake Event Data Store.

pub fn get_import_role_arn(&self) -> &Option<String>

The ARN of the IAM role that grants CloudWatch Logs permission to import from the CloudTrail Lake Event Data Store.

pub fn import_filter(self, input: ImportFilter) -> Self

Optional filters to constrain the import by CloudTrail event time. Times are specified in Unix timestamp milliseconds. The range of data being imported must be within the specified source's retention period.

pub fn set_import_filter(self, input: Option<ImportFilter>) -> Self

Optional filters to constrain the import by CloudTrail event time. Times are specified in Unix timestamp milliseconds. The range of data being imported must be within the specified source's retention period.

pub fn get_import_filter(&self) -> &Option<ImportFilter>

Optional filters to constrain the import by CloudTrail event time. Times are specified in Unix timestamp milliseconds. The range of data being imported must be within the specified source's retention period.