#[non_exhaustive]pub struct CreateImportTaskInputBuilder { /* private fields */ }Expand description
A builder for CreateImportTaskInput.
Implementations
Sourceimpl CreateImportTaskInputBuilder
impl CreateImportTaskInputBuilder
Sourcepub fn import_source_arn(self, input: impl Into<String>) -> Self
pub fn import_source_arn(self, input: impl Into<String>) -> Self
The ARN of the source to import from.
This field is required.Sourcepub fn set_import_source_arn(self, input: Option<String>) -> Self
pub fn set_import_source_arn(self, input: Option<String>) -> Self
The ARN of the source to import from.
Sourcepub fn get_import_source_arn(&self) -> &Option<String>
pub fn get_import_source_arn(&self) -> &Option<String>
The ARN of the source to import from.
Sourcepub fn import_role_arn(self, input: impl Into<String>) -> Self
pub fn import_role_arn(self, input: impl Into<String>) -> Self
The ARN of the IAM role that grants CloudWatch Logs permission to import from the CloudTrail Lake Event Data Store.
This field is required.Sourcepub fn set_import_role_arn(self, input: Option<String>) -> Self
pub fn set_import_role_arn(self, input: Option<String>) -> Self
The ARN of the IAM role that grants CloudWatch Logs permission to import from the CloudTrail Lake Event Data Store.
Sourcepub fn get_import_role_arn(&self) -> &Option<String>
pub fn get_import_role_arn(&self) -> &Option<String>
The ARN of the IAM role that grants CloudWatch Logs permission to import from the CloudTrail Lake Event Data Store.
Sourcepub fn import_filter(self, input: ImportFilter) -> Self
pub fn import_filter(self, input: ImportFilter) -> Self
Optional filters to constrain the import by CloudTrail event time. Times are specified in Unix timestamp milliseconds. The range of data being imported must be within the specified source's retention period.
Sourcepub fn set_import_filter(self, input: Option<ImportFilter>) -> Self
pub fn set_import_filter(self, input: Option<ImportFilter>) -> Self
Optional filters to constrain the import by CloudTrail event time. Times are specified in Unix timestamp milliseconds. The range of data being imported must be within the specified source's retention period.
Sourcepub fn get_import_filter(&self) -> &Option<ImportFilter>
pub fn get_import_filter(&self) -> &Option<ImportFilter>
Optional filters to constrain the import by CloudTrail event time. Times are specified in Unix timestamp milliseconds. The range of data being imported must be within the specified source's retention period.
Sourcepub fn build(self) -> Result<CreateImportTaskInput, BuildError>
pub fn build(self) -> Result<CreateImportTaskInput, BuildError>
Consumes the builder and constructs a CreateImportTaskInput.
Sourceimpl CreateImportTaskInputBuilder
impl CreateImportTaskInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateImportTaskOutput, SdkError<CreateImportTaskError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateImportTaskOutput, SdkError<CreateImportTaskError, HttpResponse>>
Sends a request with this input using the given client.