#[non_exhaustive]pub struct CreateImportTaskOutputBuilder { /* private fields */ }Expand description
A builder for CreateImportTaskOutput.
Implementations
Sourceimpl CreateImportTaskOutputBuilder
impl CreateImportTaskOutputBuilder
Sourcepub fn import_id(self, input: impl Into<String>) -> Self
pub fn import_id(self, input: impl Into<String>) -> Self
A unique identifier for the import task.
Sourcepub fn set_import_id(self, input: Option<String>) -> Self
pub fn set_import_id(self, input: Option<String>) -> Self
A unique identifier for the import task.
Sourcepub fn get_import_id(&self) -> &Option<String>
pub fn get_import_id(&self) -> &Option<String>
A unique identifier for the import task.
Sourcepub fn import_destination_arn(self, input: impl Into<String>) -> Self
pub fn import_destination_arn(self, input: impl Into<String>) -> Self
The ARN of the CloudWatch Logs log group created as the destination for the imported events.
Sourcepub fn set_import_destination_arn(self, input: Option<String>) -> Self
pub fn set_import_destination_arn(self, input: Option<String>) -> Self
The ARN of the CloudWatch Logs log group created as the destination for the imported events.
Sourcepub fn get_import_destination_arn(&self) -> &Option<String>
pub fn get_import_destination_arn(&self) -> &Option<String>
The ARN of the CloudWatch Logs log group created as the destination for the imported events.
Sourcepub fn creation_time(self, input: i64) -> Self
pub fn creation_time(self, input: i64) -> Self
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn set_creation_time(self, input: Option<i64>) -> Self
pub fn set_creation_time(self, input: Option<i64>) -> Self
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn get_creation_time(&self) -> &Option<i64>
pub fn get_creation_time(&self) -> &Option<i64>
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn build(self) -> CreateImportTaskOutput
pub fn build(self) -> CreateImportTaskOutput
Consumes the builder and constructs a CreateImportTaskOutput.