#[non_exhaustive]pub struct CreateImportTaskOutput {
pub import_id: Option<String>,
pub import_destination_arn: Option<String>,
pub creation_time: Option<i64>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.import_id: Option<String>A unique identifier for the import task.
import_destination_arn: Option<String>The ARN of the CloudWatch Logs log group created as the destination for the imported events.
creation_time: Option<i64>The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Implementations
Sourceimpl CreateImportTaskOutput
impl CreateImportTaskOutput
Sourcepub fn import_destination_arn(&self) -> Option<&str>
pub fn import_destination_arn(&self) -> Option<&str>
The ARN of the CloudWatch Logs log group created as the destination for the imported events.
Sourcepub fn creation_time(&self) -> Option<i64>
pub fn creation_time(&self) -> Option<i64>
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourceimpl CreateImportTaskOutput
impl CreateImportTaskOutput
Sourcepub fn builder() -> CreateImportTaskOutputBuilder
pub fn builder() -> CreateImportTaskOutputBuilder
Creates a new builder-style object to manufacture CreateImportTaskOutput.