#[non_exhaustive]pub struct CreateLogGroupInput {
pub log_group_name: Option<String>,
pub kms_key_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub log_group_class: Option<LogGroupClass>,
pub deletion_protection_enabled: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_group_name: Option<String>A name for the log group.
kms_key_id: Option<String>The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data. For more information, see Amazon Resource Names.
The key-value pairs to use for the tags.
You can grant users access to certain log groups while preventing them from accessing other log groups. To do so, tag your groups and use IAM policies that refer to those tags. To assign tags when you create a log group, you must have either the logs:TagResource or logs:TagLogGroup permission. For more information about tagging, see Tagging Amazon Web Services resources. For more information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.
log_group_class: Option<LogGroupClass>Use this parameter to specify the log group class for this log group. There are three classes:
-
The
Standardlog class supports all CloudWatch Logs features. -
The
Infrequent Accesslog class supports a subset of CloudWatch Logs features and incurs lower costs. -
Use the
Deliverylog class only for delivering Lambda logs to store in Amazon S3 or Amazon Data Firehose. Log events in log groups in the Delivery class are kept in CloudWatch Logs for only one day. This log class doesn't offer rich CloudWatch Logs capabilities such as CloudWatch Logs Insights queries.
If you omit this parameter, the default of STANDARD is used.
The value of logGroupClass can't be changed after a log group is created.
For details about the features supported by each class, see Log classes
deletion_protection_enabled: Option<bool>Use this parameter to enable deletion protection for the new log group. When enabled on a log group, deletion protection blocks all deletion operations until it is explicitly disabled. By default log groups are created without deletion protection enabled.
Implementations
Sourceimpl CreateLogGroupInput
impl CreateLogGroupInput
Sourcepub fn log_group_name(&self) -> Option<&str>
pub fn log_group_name(&self) -> Option<&str>
A name for the log group.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data. For more information, see Amazon Resource Names.
The key-value pairs to use for the tags.
You can grant users access to certain log groups while preventing them from accessing other log groups. To do so, tag your groups and use IAM policies that refer to those tags. To assign tags when you create a log group, you must have either the logs:TagResource or logs:TagLogGroup permission. For more information about tagging, see Tagging Amazon Web Services resources. For more information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.
Sourcepub fn log_group_class(&self) -> Option<&LogGroupClass>
pub fn log_group_class(&self) -> Option<&LogGroupClass>
Use this parameter to specify the log group class for this log group. There are three classes:
-
The
Standardlog class supports all CloudWatch Logs features. -
The
Infrequent Accesslog class supports a subset of CloudWatch Logs features and incurs lower costs. -
Use the
Deliverylog class only for delivering Lambda logs to store in Amazon S3 or Amazon Data Firehose. Log events in log groups in the Delivery class are kept in CloudWatch Logs for only one day. This log class doesn't offer rich CloudWatch Logs capabilities such as CloudWatch Logs Insights queries.
If you omit this parameter, the default of STANDARD is used.
The value of logGroupClass can't be changed after a log group is created.
For details about the features supported by each class, see Log classes
Sourcepub fn deletion_protection_enabled(&self) -> Option<bool>
pub fn deletion_protection_enabled(&self) -> Option<bool>
Use this parameter to enable deletion protection for the new log group. When enabled on a log group, deletion protection blocks all deletion operations until it is explicitly disabled. By default log groups are created without deletion protection enabled.
Sourceimpl CreateLogGroupInput
impl CreateLogGroupInput
Sourcepub fn builder() -> CreateLogGroupInputBuilder
pub fn builder() -> CreateLogGroupInputBuilder
Creates a new builder-style object to manufacture CreateLogGroupInput.