#[non_exhaustive]pub enum CreateLookupTableError {
AccessDeniedException(AccessDeniedException),
InvalidParameterException(InvalidParameterException),
LimitExceededException(LimitExceededException),
ResourceAlreadyExistsException(ResourceAlreadyExistsException),
ServiceUnavailableException(ServiceUnavailableException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateLookupTableError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
You don't have sufficient permissions to perform this action.
InvalidParameterException(InvalidParameterException)
A parameter is specified incorrectly.
LimitExceededException(LimitExceededException)
You have reached the maximum number of resources that can be created.
ResourceAlreadyExistsException(ResourceAlreadyExistsException)
The specified resource already exists.
The service cannot complete the request.
ValidationException(ValidationException)
One of the parameters for the request is not valid.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateLookupTableError
impl CreateLookupTableError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateLookupTableError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateLookupTableError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is CreateLookupTableError::AccessDeniedException.
Sourcepub fn is_invalid_parameter_exception(&self) -> bool
pub fn is_invalid_parameter_exception(&self) -> bool
Returns true if the error kind is CreateLookupTableError::InvalidParameterException.
Sourcepub fn is_limit_exceeded_exception(&self) -> bool
pub fn is_limit_exceeded_exception(&self) -> bool
Returns true if the error kind is CreateLookupTableError::LimitExceededException.
Sourcepub fn is_resource_already_exists_exception(&self) -> bool
pub fn is_resource_already_exists_exception(&self) -> bool
Returns true if the error kind is CreateLookupTableError::ResourceAlreadyExistsException.
Returns true if the error kind is CreateLookupTableError::ServiceUnavailableException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is CreateLookupTableError::ValidationException.