#[non_exhaustive]pub struct CreateLookupTableInput {
pub lookup_table_name: Option<String>,
pub description: Option<String>,
pub table_body: Option<String>,
pub kms_key_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lookup_table_name: Option<String>The name of the lookup table. The name must be unique within your account and Region. The name can contain only alphanumeric characters and underscores, and can be up to 256 characters long.
description: Option<String>A description of the lookup table. The description can be up to 1024 characters long.
table_body: Option<String>The CSV content of the lookup table. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.
kms_key_id: Option<String>The ARN of the KMS key to use to encrypt the lookup table data. If you don't specify a key, the data is encrypted with an Amazon Web Services-owned key.
A list of key-value pairs to associate with the lookup table. You can associate as many as 50 tags with a lookup table. Tags can help you organize and categorize your resources.
Implementations
Sourceimpl CreateLookupTableInput
impl CreateLookupTableInput
Sourcepub fn lookup_table_name(&self) -> Option<&str>
pub fn lookup_table_name(&self) -> Option<&str>
The name of the lookup table. The name must be unique within your account and Region. The name can contain only alphanumeric characters and underscores, and can be up to 256 characters long.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the lookup table. The description can be up to 1024 characters long.
Sourcepub fn table_body(&self) -> Option<&str>
pub fn table_body(&self) -> Option<&str>
The CSV content of the lookup table. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ARN of the KMS key to use to encrypt the lookup table data. If you don't specify a key, the data is encrypted with an Amazon Web Services-owned key.
A list of key-value pairs to associate with the lookup table. You can associate as many as 50 tags with a lookup table. Tags can help you organize and categorize your resources.
Sourceimpl CreateLookupTableInput
impl CreateLookupTableInput
Sourcepub fn builder() -> CreateLookupTableInputBuilder
pub fn builder() -> CreateLookupTableInputBuilder
Creates a new builder-style object to manufacture CreateLookupTableInput.