#[non_exhaustive]pub enum DeleteSyslogConfigurationError {
AccessDeniedException(AccessDeniedException),
InvalidOperationException(InvalidOperationException),
InvalidParameterException(InvalidParameterException),
OperationAbortedException(OperationAbortedException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceUnavailableException(ServiceUnavailableException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the DeleteSyslogConfigurationError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
You don't have sufficient permissions to perform this action.
InvalidOperationException(InvalidOperationException)
The operation is not valid on the specified resource.
InvalidParameterException(InvalidParameterException)
A parameter is specified incorrectly.
OperationAbortedException(OperationAbortedException)
Multiple concurrent requests to update the same resource were in conflict.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource does not exist.
The service cannot complete the request.
ThrottlingException(ThrottlingException)
The request was throttled because of quota limits.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DeleteSyslogConfigurationError
impl DeleteSyslogConfigurationError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DeleteSyslogConfigurationError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DeleteSyslogConfigurationError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is DeleteSyslogConfigurationError::AccessDeniedException.
Sourcepub fn is_invalid_operation_exception(&self) -> bool
pub fn is_invalid_operation_exception(&self) -> bool
Returns true if the error kind is DeleteSyslogConfigurationError::InvalidOperationException.
Sourcepub fn is_invalid_parameter_exception(&self) -> bool
pub fn is_invalid_parameter_exception(&self) -> bool
Returns true if the error kind is DeleteSyslogConfigurationError::InvalidParameterException.
Sourcepub fn is_operation_aborted_exception(&self) -> bool
pub fn is_operation_aborted_exception(&self) -> bool
Returns true if the error kind is DeleteSyslogConfigurationError::OperationAbortedException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is DeleteSyslogConfigurationError::ResourceNotFoundException.
Returns true if the error kind is DeleteSyslogConfigurationError::ServiceUnavailableException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is DeleteSyslogConfigurationError::ThrottlingException.