#[non_exhaustive]pub struct PutQueryDefinitionInput {
pub query_language: Option<QueryLanguage>,
pub name: Option<String>,
pub query_definition_id: Option<String>,
pub log_group_names: Option<Vec<String>>,
pub query_string: Option<String>,
pub client_token: Option<String>,
pub parameters: Option<Vec<QueryParameter>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_language: Option<QueryLanguage>Specify the query language to use for this query. The options are Logs Insights QL, OpenSearch PPL, and OpenSearch SQL. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
name: Option<String>A name for the query definition. If you are saving numerous query definitions, we recommend that you name them. This way, you can find the ones you want by using the first part of the name as a filter in the queryDefinitionNamePrefix parameter of DescribeQueryDefinitions.
query_definition_id: Option<String>If you are updating a query definition, use this parameter to specify the ID of the query definition that you want to update. You can use DescribeQueryDefinitions to retrieve the IDs of your saved query definitions.
If you are creating a query definition, do not specify this parameter. CloudWatch generates a unique ID for the new query definition and include it in the response to this operation.
log_group_names: Option<Vec<String>>Use this parameter to include specific log groups as part of your query definition. If your query uses the OpenSearch Service query language, you specify the log group names inside the querystring instead of here.
If you are updating an existing query definition for the Logs Insights QL or OpenSearch Service PPL and you omit this parameter, then the updated definition will contain no log groups.
query_string: Option<String>The query string to use for this definition. For more information, see CloudWatch Logs Insights Query Syntax.
client_token: Option<String>Used as an idempotency token, to avoid returning an exception if the service receives the same request twice because of a network error.
parameters: Option<Vec<QueryParameter>>Use this parameter to include specific query parameters as part of your query definition. Query parameters are supported only for Logs Insights QL queries. Query parameters allow you to use placeholder variables in your query string that are substituted with values at execution time. Use the {{parameterName}} syntax in your query string to reference a parameter.
Implementations
Sourceimpl PutQueryDefinitionInput
impl PutQueryDefinitionInput
Sourcepub fn query_language(&self) -> Option<&QueryLanguage>
pub fn query_language(&self) -> Option<&QueryLanguage>
Specify the query language to use for this query. The options are Logs Insights QL, OpenSearch PPL, and OpenSearch SQL. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
A name for the query definition. If you are saving numerous query definitions, we recommend that you name them. This way, you can find the ones you want by using the first part of the name as a filter in the queryDefinitionNamePrefix parameter of DescribeQueryDefinitions.
Sourcepub fn query_definition_id(&self) -> Option<&str>
pub fn query_definition_id(&self) -> Option<&str>
If you are updating a query definition, use this parameter to specify the ID of the query definition that you want to update. You can use DescribeQueryDefinitions to retrieve the IDs of your saved query definitions.
If you are creating a query definition, do not specify this parameter. CloudWatch generates a unique ID for the new query definition and include it in the response to this operation.
Sourcepub fn log_group_names(&self) -> &[String]
pub fn log_group_names(&self) -> &[String]
Use this parameter to include specific log groups as part of your query definition. If your query uses the OpenSearch Service query language, you specify the log group names inside the querystring instead of here.
If you are updating an existing query definition for the Logs Insights QL or OpenSearch Service PPL and you omit this parameter, then the updated definition will contain no log groups.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .log_group_names.is_none().
Sourcepub fn query_string(&self) -> Option<&str>
pub fn query_string(&self) -> Option<&str>
The query string to use for this definition. For more information, see CloudWatch Logs Insights Query Syntax.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Used as an idempotency token, to avoid returning an exception if the service receives the same request twice because of a network error.
Sourcepub fn parameters(&self) -> &[QueryParameter]
pub fn parameters(&self) -> &[QueryParameter]
Use this parameter to include specific query parameters as part of your query definition. Query parameters are supported only for Logs Insights QL queries. Query parameters allow you to use placeholder variables in your query string that are substituted with values at execution time. Use the {{parameterName}} syntax in your query string to reference a parameter.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .parameters.is_none().
Sourceimpl PutQueryDefinitionInput
impl PutQueryDefinitionInput
Sourcepub fn builder() -> PutQueryDefinitionInputBuilder
pub fn builder() -> PutQueryDefinitionInputBuilder
Creates a new builder-style object to manufacture PutQueryDefinitionInput.