#[non_exhaustive]pub struct ConfigurationTemplateDeliveryConfigValuesBuilder { /* private fields */ }Expand description
A builder for ConfigurationTemplateDeliveryConfigValues.
Implementations
Sourceimpl ConfigurationTemplateDeliveryConfigValuesBuilder
impl ConfigurationTemplateDeliveryConfigValuesBuilder
Sourcepub fn record_fields(self, input: impl Into<String>) -> Self
pub fn record_fields(self, input: impl Into<String>) -> Self
Appends an item to record_fields.
To override the contents of this collection use set_record_fields.
The default record fields that will be delivered when a list of record fields is not provided in a CreateDelivery operation.
Sourcepub fn set_record_fields(self, input: Option<Vec<String>>) -> Self
pub fn set_record_fields(self, input: Option<Vec<String>>) -> Self
The default record fields that will be delivered when a list of record fields is not provided in a CreateDelivery operation.
Sourcepub fn get_record_fields(&self) -> &Option<Vec<String>>
pub fn get_record_fields(&self) -> &Option<Vec<String>>
The default record fields that will be delivered when a list of record fields is not provided in a CreateDelivery operation.
Sourcepub fn field_delimiter(self, input: impl Into<String>) -> Self
pub fn field_delimiter(self, input: impl Into<String>) -> Self
The default field delimiter that is used in a CreateDelivery operation when the field delimiter is not specified in that operation. The field delimiter is used only when the final output delivery is in Plain, W3C, or Raw format.
Sourcepub fn set_field_delimiter(self, input: Option<String>) -> Self
pub fn set_field_delimiter(self, input: Option<String>) -> Self
The default field delimiter that is used in a CreateDelivery operation when the field delimiter is not specified in that operation. The field delimiter is used only when the final output delivery is in Plain, W3C, or Raw format.
Sourcepub fn get_field_delimiter(&self) -> &Option<String>
pub fn get_field_delimiter(&self) -> &Option<String>
The default field delimiter that is used in a CreateDelivery operation when the field delimiter is not specified in that operation. The field delimiter is used only when the final output delivery is in Plain, W3C, or Raw format.
Sourcepub fn s3_delivery_configuration(self, input: S3DeliveryConfiguration) -> Self
pub fn s3_delivery_configuration(self, input: S3DeliveryConfiguration) -> Self
The delivery parameters that are used when you create a delivery to a delivery destination that is an S3 Bucket.
Sourcepub fn set_s3_delivery_configuration(
self,
input: Option<S3DeliveryConfiguration>,
) -> Self
pub fn set_s3_delivery_configuration( self, input: Option<S3DeliveryConfiguration>, ) -> Self
The delivery parameters that are used when you create a delivery to a delivery destination that is an S3 Bucket.
Sourcepub fn get_s3_delivery_configuration(&self) -> &Option<S3DeliveryConfiguration>
pub fn get_s3_delivery_configuration(&self) -> &Option<S3DeliveryConfiguration>
The delivery parameters that are used when you create a delivery to a delivery destination that is an S3 Bucket.
Sourcepub fn build(self) -> ConfigurationTemplateDeliveryConfigValues
pub fn build(self) -> ConfigurationTemplateDeliveryConfigValues
Consumes the builder and constructs a ConfigurationTemplateDeliveryConfigValues.