DeliverySourceConfigurationSchemaBuilder

Struct DeliverySourceConfigurationSchemaBuilder 

#[non_exhaustive]
pub struct DeliverySourceConfigurationSchemaBuilder { /* private fields */ }
Implementations

Source

impl DeliverySourceConfigurationSchemaBuilder

pub fn key_name(self, input: impl Into<String>) -> Self

The name of the configuration.

This field is required.
pub fn set_key_name(self, input: Option<String>) -> Self

The name of the configuration.

pub fn get_key_name(&self) -> &Option<String>

The name of the configuration.

pub fn value_type( self, input: DeliverySourceConfigurationSchemaValueType, ) -> Self

The data type of the configuration value. Valid values are string, boolean, int, double, and long.

This field is required.
pub fn set_value_type( self, input: Option<DeliverySourceConfigurationSchemaValueType>, ) -> Self

The data type of the configuration value. Valid values are string, boolean, int, double, and long.

pub fn get_value_type( &self, ) -> &Option<DeliverySourceConfigurationSchemaValueType>

The data type of the configuration value. Valid values are string, boolean, int, double, and long.

pub fn default_value(self, input: impl Into<String>) -> Self

The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.

This field is required.
pub fn set_default_value(self, input: Option<String>) -> Self

The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.

pub fn get_default_value(&self) -> &Option<String>

The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.

pub fn supported_values(self, input: impl Into<String>) -> Self

Appends an item to supported_values.

To override the contents of this collection use set_supported_values.

The list of allowed values for the configuration. Empty for free-form configuration.

pub fn set_supported_values(self, input: Option<Vec<String>>) -> Self

The list of allowed values for the configuration. Empty for free-form configuration.

pub fn get_supported_values(&self) -> &Option<Vec<String>>

The list of allowed values for the configuration. Empty for free-form configuration.

pub fn min_value(self, input: f64) -> Self

The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

pub fn set_min_value(self, input: Option<f64>) -> Self

The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

pub fn get_min_value(&self) -> &Option<f64>

The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

pub fn max_value(self, input: f64) -> Self

The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

pub fn set_max_value(self, input: Option<f64>) -> Self

The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

pub fn get_max_value(&self) -> &Option<f64>

The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

pub fn build(self) -> Result<DeliverySourceConfigurationSchema, BuildError>

Consumes the builder and constructs a DeliverySourceConfigurationSchema. This method will fail if any of the following fields are not set: