#[non_exhaustive]pub struct InputLogEventBuilder { /* private fields */ }Expand description
A builder for InputLogEvent.
Implementations
Sourceimpl InputLogEventBuilder
impl InputLogEventBuilder
Sourcepub fn timestamp(self, input: i64) -> Self
pub fn timestamp(self, input: i64) -> Self
The time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn set_timestamp(self, input: Option<i64>) -> Self
pub fn set_timestamp(self, input: Option<i64>) -> Self
The time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn get_timestamp(&self) -> &Option<i64>
pub fn get_timestamp(&self) -> &Option<i64>
The time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn message(self, input: impl Into<String>) -> Self
pub fn message(self, input: impl Into<String>) -> Self
The raw event message. Each log event can be no larger than 1 MB.
This field is required.Sourcepub fn set_message(self, input: Option<String>) -> Self
pub fn set_message(self, input: Option<String>) -> Self
The raw event message. Each log event can be no larger than 1 MB.
Sourcepub fn get_message(&self) -> &Option<String>
pub fn get_message(&self) -> &Option<String>
The raw event message. Each log event can be no larger than 1 MB.
Sourcepub fn build(self) -> Result<InputLogEvent, BuildError>
pub fn build(self) -> Result<InputLogEvent, BuildError>
Consumes the builder and constructs a InputLogEvent.
This method will fail if any of the following fields are not set: