#[non_exhaustive]pub struct QueryInfoBuilder { /* private fields */ }Expand description
A builder for QueryInfo.
Implementations
Sourceimpl QueryInfoBuilder
impl QueryInfoBuilder
Sourcepub fn query_language(self, input: QueryLanguage) -> Self
pub fn query_language(self, input: QueryLanguage) -> Self
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
Sourcepub fn set_query_language(self, input: Option<QueryLanguage>) -> Self
pub fn set_query_language(self, input: Option<QueryLanguage>) -> Self
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
Sourcepub fn get_query_language(&self) -> &Option<QueryLanguage>
pub fn get_query_language(&self) -> &Option<QueryLanguage>
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
Sourcepub fn set_query_id(self, input: Option<String>) -> Self
pub fn set_query_id(self, input: Option<String>) -> Self
The unique ID number of this query.
Sourcepub fn get_query_id(&self) -> &Option<String>
pub fn get_query_id(&self) -> &Option<String>
The unique ID number of this query.
Sourcepub fn query_string(self, input: impl Into<String>) -> Self
pub fn query_string(self, input: impl Into<String>) -> Self
The query string used in this query.
Sourcepub fn set_query_string(self, input: Option<String>) -> Self
pub fn set_query_string(self, input: Option<String>) -> Self
The query string used in this query.
Sourcepub fn get_query_string(&self) -> &Option<String>
pub fn get_query_string(&self) -> &Option<String>
The query string used in this query.
Sourcepub fn status(self, input: QueryStatus) -> Self
pub fn status(self, input: QueryStatus) -> Self
The status of this query. Possible values are Cancelled, Complete, Failed, Running, Scheduled, and Unknown.
Sourcepub fn set_status(self, input: Option<QueryStatus>) -> Self
pub fn set_status(self, input: Option<QueryStatus>) -> Self
The status of this query. Possible values are Cancelled, Complete, Failed, Running, Scheduled, and Unknown.
Sourcepub fn get_status(&self) -> &Option<QueryStatus>
pub fn get_status(&self) -> &Option<QueryStatus>
The status of this query. Possible values are Cancelled, Complete, Failed, Running, Scheduled, and Unknown.
Sourcepub fn create_time(self, input: i64) -> Self
pub fn create_time(self, input: i64) -> Self
The date and time that this query was created.
Sourcepub fn set_create_time(self, input: Option<i64>) -> Self
pub fn set_create_time(self, input: Option<i64>) -> Self
The date and time that this query was created.
Sourcepub fn get_create_time(&self) -> &Option<i64>
pub fn get_create_time(&self) -> &Option<i64>
The date and time that this query was created.
Sourcepub fn log_group_name(self, input: impl Into<String>) -> Self
pub fn log_group_name(self, input: impl Into<String>) -> Self
The name of the log group scanned by this query.
Sourcepub fn set_log_group_name(self, input: Option<String>) -> Self
pub fn set_log_group_name(self, input: Option<String>) -> Self
The name of the log group scanned by this query.
Sourcepub fn get_log_group_name(&self) -> &Option<String>
pub fn get_log_group_name(&self) -> &Option<String>
The name of the log group scanned by this query.
Sourcepub fn query_duration(self, input: i64) -> Self
pub fn query_duration(self, input: i64) -> Self
The duration in milliseconds that the query took to execute.
Sourcepub fn set_query_duration(self, input: Option<i64>) -> Self
pub fn set_query_duration(self, input: Option<i64>) -> Self
The duration in milliseconds that the query took to execute.
Sourcepub fn get_query_duration(&self) -> &Option<i64>
pub fn get_query_duration(&self) -> &Option<i64>
The duration in milliseconds that the query took to execute.
Sourcepub fn bytes_scanned(self, input: f64) -> Self
pub fn bytes_scanned(self, input: f64) -> Self
The total number of bytes scanned by the query. This indicates the cost associated with the query.
Sourcepub fn set_bytes_scanned(self, input: Option<f64>) -> Self
pub fn set_bytes_scanned(self, input: Option<f64>) -> Self
The total number of bytes scanned by the query. This indicates the cost associated with the query.
Sourcepub fn get_bytes_scanned(&self) -> &Option<f64>
pub fn get_bytes_scanned(&self) -> &Option<f64>
The total number of bytes scanned by the query. This indicates the cost associated with the query.
Sourcepub fn user_identity(self, input: impl Into<String>) -> Self
pub fn user_identity(self, input: impl Into<String>) -> Self
The ARN of the user who ran the query.
Sourcepub fn set_user_identity(self, input: Option<String>) -> Self
pub fn set_user_identity(self, input: Option<String>) -> Self
The ARN of the user who ran the query.
Sourcepub fn get_user_identity(&self) -> &Option<String>
pub fn get_user_identity(&self) -> &Option<String>
The ARN of the user who ran the query.