#[non_exhaustive]pub struct S3TableIntegrationSourceBuilder { /* private fields */ }Expand description
A builder for S3TableIntegrationSource.
Implementations
Sourceimpl S3TableIntegrationSourceBuilder
impl S3TableIntegrationSourceBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier for this data source association.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier for this data source association.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier for this data source association.
Sourcepub fn data_source(self, input: DataSource) -> Self
pub fn data_source(self, input: DataSource) -> Self
The data source associated with the S3 Table Integration.
Sourcepub fn set_data_source(self, input: Option<DataSource>) -> Self
pub fn set_data_source(self, input: Option<DataSource>) -> Self
The data source associated with the S3 Table Integration.
Sourcepub fn get_data_source(&self) -> &Option<DataSource>
pub fn get_data_source(&self) -> &Option<DataSource>
The data source associated with the S3 Table Integration.
Sourcepub fn status(self, input: S3TableIntegrationSourceStatus) -> Self
pub fn status(self, input: S3TableIntegrationSourceStatus) -> Self
The current status of the data source association.
Sourcepub fn set_status(self, input: Option<S3TableIntegrationSourceStatus>) -> Self
pub fn set_status(self, input: Option<S3TableIntegrationSourceStatus>) -> Self
The current status of the data source association.
Sourcepub fn get_status(&self) -> &Option<S3TableIntegrationSourceStatus>
pub fn get_status(&self) -> &Option<S3TableIntegrationSourceStatus>
The current status of the data source association.
Sourcepub fn status_reason(self, input: impl Into<String>) -> Self
pub fn status_reason(self, input: impl Into<String>) -> Self
Additional information about the status of the data source association.
Sourcepub fn set_status_reason(self, input: Option<String>) -> Self
pub fn set_status_reason(self, input: Option<String>) -> Self
Additional information about the status of the data source association.
Sourcepub fn get_status_reason(&self) -> &Option<String>
pub fn get_status_reason(&self) -> &Option<String>
Additional information about the status of the data source association.
Sourcepub fn created_time_stamp(self, input: i64) -> Self
pub fn created_time_stamp(self, input: i64) -> Self
The timestamp when the data source association was created.
Sourcepub fn set_created_time_stamp(self, input: Option<i64>) -> Self
pub fn set_created_time_stamp(self, input: Option<i64>) -> Self
The timestamp when the data source association was created.
Sourcepub fn get_created_time_stamp(&self) -> &Option<i64>
pub fn get_created_time_stamp(&self) -> &Option<i64>
The timestamp when the data source association was created.
Sourcepub fn parent_source_identifier(self, input: impl Into<String>) -> Self
pub fn parent_source_identifier(self, input: impl Into<String>) -> Self
The identifier of the parent data source for this association.
Sourcepub fn set_parent_source_identifier(self, input: Option<String>) -> Self
pub fn set_parent_source_identifier(self, input: Option<String>) -> Self
The identifier of the parent data source for this association.
Sourcepub fn get_parent_source_identifier(&self) -> &Option<String>
pub fn get_parent_source_identifier(&self) -> &Option<String>
The identifier of the parent data source for this association.
Sourcepub fn build(self) -> S3TableIntegrationSource
pub fn build(self) -> S3TableIntegrationSource
Consumes the builder and constructs a S3TableIntegrationSource.