#[non_exhaustive]pub struct SyslogConfigurationBuilder { /* private fields */ }Expand description
A builder for SyslogConfiguration.
Implementations
Sourceimpl SyslogConfigurationBuilder
impl SyslogConfigurationBuilder
Sourcepub fn log_group_arn(self, input: impl Into<String>) -> Self
pub fn log_group_arn(self, input: impl Into<String>) -> Self
The ARN of the log group associated with this syslog configuration.
Sourcepub fn set_log_group_arn(self, input: Option<String>) -> Self
pub fn set_log_group_arn(self, input: Option<String>) -> Self
The ARN of the log group associated with this syslog configuration.
Sourcepub fn get_log_group_arn(&self) -> &Option<String>
pub fn get_log_group_arn(&self) -> &Option<String>
The ARN of the log group associated with this syslog configuration.
Sourcepub fn source_type(self, input: SyslogSourceType) -> Self
pub fn source_type(self, input: SyslogSourceType) -> Self
The source type for the syslog configuration.
Sourcepub fn set_source_type(self, input: Option<SyslogSourceType>) -> Self
pub fn set_source_type(self, input: Option<SyslogSourceType>) -> Self
The source type for the syslog configuration.
Sourcepub fn get_source_type(&self) -> &Option<SyslogSourceType>
pub fn get_source_type(&self) -> &Option<SyslogSourceType>
The source type for the syslog configuration.
Sourcepub fn vpc_endpoint_id(self, input: impl Into<String>) -> Self
pub fn vpc_endpoint_id(self, input: impl Into<String>) -> Self
The ID of the VPC endpoint used for syslog ingestion.
Sourcepub fn set_vpc_endpoint_id(self, input: Option<String>) -> Self
pub fn set_vpc_endpoint_id(self, input: Option<String>) -> Self
The ID of the VPC endpoint used for syslog ingestion.
Sourcepub fn get_vpc_endpoint_id(&self) -> &Option<String>
pub fn get_vpc_endpoint_id(&self) -> &Option<String>
The ID of the VPC endpoint used for syslog ingestion.
Sourcepub fn created_at(self, input: i64) -> Self
pub fn created_at(self, input: i64) -> Self
The time when the syslog configuration was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn set_created_at(self, input: Option<i64>) -> Self
pub fn set_created_at(self, input: Option<i64>) -> Self
The time when the syslog configuration was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn get_created_at(&self) -> &Option<i64>
pub fn get_created_at(&self) -> &Option<i64>
The time when the syslog configuration was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn build(self) -> SyslogConfiguration
pub fn build(self) -> SyslogConfiguration
Consumes the builder and constructs a SyslogConfiguration.