#[non_exhaustive]pub struct AggregateLogGroupSummary {
pub log_group_count: Option<i32>,
pub grouping_identifiers: Option<Vec<GroupingIdentifier>>,
}Expand description
Contains an aggregate summary of log groups grouped by data source characteristics, including the count of log groups and their grouping identifiers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_group_count: Option<i32>The number of log groups in this aggregate summary group.
grouping_identifiers: Option<Vec<GroupingIdentifier>>An array of key-value pairs that identify the data source characteristics used to group the log groups.
The size and content of this array depends on the groupBy parameter specified in the request.
Implementations
Sourceimpl AggregateLogGroupSummary
impl AggregateLogGroupSummary
Sourcepub fn log_group_count(&self) -> Option<i32>
pub fn log_group_count(&self) -> Option<i32>
The number of log groups in this aggregate summary group.
Sourcepub fn grouping_identifiers(&self) -> &[GroupingIdentifier]
pub fn grouping_identifiers(&self) -> &[GroupingIdentifier]
An array of key-value pairs that identify the data source characteristics used to group the log groups.
The size and content of this array depends on the groupBy parameter specified in the request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .grouping_identifiers.is_none().
Sourceimpl AggregateLogGroupSummary
impl AggregateLogGroupSummary
Sourcepub fn builder() -> AggregateLogGroupSummaryBuilder
pub fn builder() -> AggregateLogGroupSummaryBuilder
Creates a new builder-style object to manufacture AggregateLogGroupSummary.