#[non_exhaustive]pub struct DeliveryDestination {
pub name: Option<String>,
pub arn: Option<String>,
pub delivery_destination_type: Option<DeliveryDestinationType>,
pub output_format: Option<OutputFormat>,
pub delivery_destination_configuration: Option<DeliveryDestinationConfiguration>,
pub tags: Option<HashMap<String, String>>,
}Expand description
This structure contains information about one delivery destination in your account. A delivery destination is an Amazon Web Services resource that represents an Amazon Web Services service that logs can be sent to. CloudWatch Logs, Amazon S3, Firehose, and X-Ray are supported as delivery destinations.
To configure logs delivery between a supported Amazon Web Services service and a destination, you must do the following:
-
Create a delivery source, which is a logical object that represents the resource that is actually sending the logs. For more information, see PutDeliverySource.
-
Create a delivery destination, which is a logical object that represents the actual delivery destination.
-
If you are delivering logs cross-account, you must use PutDeliveryDestinationPolicy in the destination account to assign an IAM policy to the destination. This policy allows delivery to that destination.
-
Create a delivery by pairing exactly one delivery source and one delivery destination. For more information, see CreateDelivery.
You can configure a single delivery source to send logs to multiple destinations by creating multiple deliveries. You can also create multiple deliveries to configure multiple delivery sources to send logs to the same delivery destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of this delivery destination.
arn: Option<String>The Amazon Resource Name (ARN) that uniquely identifies this delivery destination.
delivery_destination_type: Option<DeliveryDestinationType>Displays whether this delivery destination is CloudWatch Logs, Amazon S3, Firehose, or X-Ray.
output_format: Option<OutputFormat>The format of the logs that are sent to this delivery destination.
delivery_destination_configuration: Option<DeliveryDestinationConfiguration>A structure that contains the ARN of the Amazon Web Services resource that will receive the logs.
The tags that have been assigned to this delivery destination.
Implementations
Sourceimpl DeliveryDestination
impl DeliveryDestination
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) that uniquely identifies this delivery destination.
Sourcepub fn delivery_destination_type(&self) -> Option<&DeliveryDestinationType>
pub fn delivery_destination_type(&self) -> Option<&DeliveryDestinationType>
Displays whether this delivery destination is CloudWatch Logs, Amazon S3, Firehose, or X-Ray.
Sourcepub fn output_format(&self) -> Option<&OutputFormat>
pub fn output_format(&self) -> Option<&OutputFormat>
The format of the logs that are sent to this delivery destination.
Sourcepub fn delivery_destination_configuration(
&self,
) -> Option<&DeliveryDestinationConfiguration>
pub fn delivery_destination_configuration( &self, ) -> Option<&DeliveryDestinationConfiguration>
A structure that contains the ARN of the Amazon Web Services resource that will receive the logs.
The tags that have been assigned to this delivery destination.
Sourceimpl DeliveryDestination
impl DeliveryDestination
Sourcepub fn builder() -> DeliveryDestinationBuilder
pub fn builder() -> DeliveryDestinationBuilder
Creates a new builder-style object to manufacture DeliveryDestination.