#[non_exhaustive]pub struct DeliveryDestinationConfiguration {
pub destination_resource_arn: String,
}Expand description
A structure that contains information about one logs delivery destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination_resource_arn: StringThe ARN of the Amazon Web Services destination that this delivery destination represents. That Amazon Web Services destination can be a log group in CloudWatch Logs, an Amazon S3 bucket, or a delivery stream in Firehose.
Implementations
Sourceimpl DeliveryDestinationConfiguration
impl DeliveryDestinationConfiguration
Sourcepub fn destination_resource_arn(&self) -> &str
pub fn destination_resource_arn(&self) -> &str
The ARN of the Amazon Web Services destination that this delivery destination represents. That Amazon Web Services destination can be a log group in CloudWatch Logs, an Amazon S3 bucket, or a delivery stream in Firehose.
Sourceimpl DeliveryDestinationConfiguration
impl DeliveryDestinationConfiguration
Sourcepub fn builder() -> DeliveryDestinationConfigurationBuilder
pub fn builder() -> DeliveryDestinationConfigurationBuilder
Creates a new builder-style object to manufacture DeliveryDestinationConfiguration.