#[non_exhaustive]pub struct DeliverySourceConfigurationSchema {
pub key_name: String,
pub value_type: DeliverySourceConfigurationSchemaValueType,
pub default_value: String,
pub supported_values: Option<Vec<String>>,
pub min_value: Option<f64>,
pub max_value: Option<f64>,
}Expand description
A structure that describes a single configuration for a log type, including its name, value type, default value, and the range of supported values.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_name: StringThe name of the configuration.
value_type: DeliverySourceConfigurationSchemaValueTypeThe data type of the configuration value. Valid values are string, boolean, int, double, and long.
default_value: StringThe default value of the configuration that is used when a value is not specified in a PutDeliverySource request.
supported_values: Option<Vec<String>>The list of allowed values for the configuration. Empty for free-form configuration.
min_value: Option<f64>The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
max_value: Option<f64>The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Implementations
Sourceimpl DeliverySourceConfigurationSchema
impl DeliverySourceConfigurationSchema
Sourcepub fn value_type(&self) -> &DeliverySourceConfigurationSchemaValueType
pub fn value_type(&self) -> &DeliverySourceConfigurationSchemaValueType
The data type of the configuration value. Valid values are string, boolean, int, double, and long.
Sourcepub fn default_value(&self) -> &str
pub fn default_value(&self) -> &str
The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.
Sourcepub fn supported_values(&self) -> &[String]
pub fn supported_values(&self) -> &[String]
The list of allowed values for the configuration. Empty for free-form configuration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .supported_values.is_none().
Sourceimpl DeliverySourceConfigurationSchema
impl DeliverySourceConfigurationSchema
Sourcepub fn builder() -> DeliverySourceConfigurationSchemaBuilder
pub fn builder() -> DeliverySourceConfigurationSchemaBuilder
Creates a new builder-style object to manufacture DeliverySourceConfigurationSchema.