#[non_exhaustive]pub struct Import {
pub import_id: Option<String>,
pub import_source_arn: Option<String>,
pub import_status: Option<ImportStatus>,
pub import_destination_arn: Option<String>,
pub import_statistics: Option<ImportStatistics>,
pub import_filter: Option<ImportFilter>,
pub creation_time: Option<i64>,
pub last_updated_time: Option<i64>,
pub error_message: Option<String>,
}Expand description
An import job to move data from CloudTrail Event Data Store to CloudWatch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.import_id: Option<String>The unique identifier of the import task.
import_source_arn: Option<String>The ARN of the CloudTrail Lake Event Data Store being imported from.
import_status: Option<ImportStatus>The current status of the import task. Valid values are IN_PROGRESS, CANCELLED, COMPLETED and FAILED.
import_destination_arn: Option<String>The ARN of the managed CloudWatch Logs log group where the events are being imported to.
import_statistics: Option<ImportStatistics>Statistics about the import progress
import_filter: Option<ImportFilter>The filter criteria used for this import task.
creation_time: Option<i64>The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
last_updated_time: Option<i64>The timestamp when the import task was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
error_message: Option<String>Error message related to any failed imports
Implementations
Sourceimpl Import
impl Import
Sourcepub fn import_source_arn(&self) -> Option<&str>
pub fn import_source_arn(&self) -> Option<&str>
The ARN of the CloudTrail Lake Event Data Store being imported from.
Sourcepub fn import_status(&self) -> Option<&ImportStatus>
pub fn import_status(&self) -> Option<&ImportStatus>
The current status of the import task. Valid values are IN_PROGRESS, CANCELLED, COMPLETED and FAILED.
Sourcepub fn import_destination_arn(&self) -> Option<&str>
pub fn import_destination_arn(&self) -> Option<&str>
The ARN of the managed CloudWatch Logs log group where the events are being imported to.
Sourcepub fn import_statistics(&self) -> Option<&ImportStatistics>
pub fn import_statistics(&self) -> Option<&ImportStatistics>
Statistics about the import progress
Sourcepub fn import_filter(&self) -> Option<&ImportFilter>
pub fn import_filter(&self) -> Option<&ImportFilter>
The filter criteria used for this import task.
Sourcepub fn creation_time(&self) -> Option<i64>
pub fn creation_time(&self) -> Option<i64>
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn last_updated_time(&self) -> Option<i64>
pub fn last_updated_time(&self) -> Option<i64>
The timestamp when the import task was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
Error message related to any failed imports