#[non_exhaustive]pub struct ImportBatch {
pub batch_id: String,
pub status: ImportStatus,
pub error_message: Option<String>,
}Expand description
A collection of events being imported to CloudWatch
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.batch_id: StringThe unique identifier of the import batch.
status: ImportStatusThe current status of the import batch. Valid values are IN_PROGRESS, CANCELLED, COMPLETED and FAILED.
error_message: Option<String>The error message if the batch failed to import. Only present when status is FAILED.
Implementations
Sourceimpl ImportBatch
impl ImportBatch
Sourcepub fn status(&self) -> &ImportStatus
pub fn status(&self) -> &ImportStatus
The current status of the import batch. Valid values are IN_PROGRESS, CANCELLED, COMPLETED and FAILED.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The error message if the batch failed to import. Only present when status is FAILED.
Sourceimpl ImportBatch
impl ImportBatch
Sourcepub fn builder() -> ImportBatchBuilder
pub fn builder() -> ImportBatchBuilder
Creates a new builder-style object to manufacture ImportBatch.