#[non_exhaustive]pub struct InputLogEvent {
pub timestamp: i64,
pub message: String,
}Expand description
Represents a log event, which is a record of activity that was recorded by the application or resource being monitored.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp: i64The time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
message: StringThe raw event message. Each log event can be no larger than 1 MB.
Implementations
Sourceimpl InputLogEvent
impl InputLogEvent
Sourceimpl InputLogEvent
impl InputLogEvent
Sourcepub fn builder() -> InputLogEventBuilder
pub fn builder() -> InputLogEventBuilder
Creates a new builder-style object to manufacture InputLogEvent.