#[non_exhaustive]pub struct LiveTailSessionMetadata {
pub sampled: bool,
}Expand description
This object contains the metadata for one LiveTailSessionUpdate structure. It indicates whether that update includes only a sample of 500 log events out of a larger number of ingested log events, or if it contains all of the matching log events ingested during that second of time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sampled: boolIf this is true, then more than 500 log events matched the request for this update, and the sessionResults includes a sample of 500 of those events.
If this is false, then 500 or fewer log events matched the request for this update, so no sampling was necessary. In this case, the sessionResults array includes all log events that matched your request during this time.
Implementations
Sourceimpl LiveTailSessionMetadata
impl LiveTailSessionMetadata
Sourcepub fn sampled(&self) -> bool
pub fn sampled(&self) -> bool
If this is true, then more than 500 log events matched the request for this update, and the sessionResults includes a sample of 500 of those events.
If this is false, then 500 or fewer log events matched the request for this update, so no sampling was necessary. In this case, the sessionResults array includes all log events that matched your request during this time.
Sourceimpl LiveTailSessionMetadata
impl LiveTailSessionMetadata
Sourcepub fn builder() -> LiveTailSessionMetadataBuilder
pub fn builder() -> LiveTailSessionMetadataBuilder
Creates a new builder-style object to manufacture LiveTailSessionMetadata.