#[non_exhaustive]pub struct LiveTailSessionUpdate {
pub session_metadata: Option<LiveTailSessionMetadata>,
pub session_results: Option<Vec<LiveTailSessionLogEvent>>,
}Expand description
This object contains the log events and metadata for a Live Tail session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_metadata: Option<LiveTailSessionMetadata>This object contains the session metadata for a Live Tail session.
session_results: Option<Vec<LiveTailSessionLogEvent>>An array, where each member of the array includes the information for one log event in the Live Tail session.
A sessionResults array can include as many as 500 log events. If the number of log events matching the request exceeds 500 per second, the log events are sampled down to 500 log events to be included in each sessionUpdate structure.
Implementations
Sourceimpl LiveTailSessionUpdate
impl LiveTailSessionUpdate
Sourcepub fn session_metadata(&self) -> Option<&LiveTailSessionMetadata>
pub fn session_metadata(&self) -> Option<&LiveTailSessionMetadata>
This object contains the session metadata for a Live Tail session.
Sourcepub fn session_results(&self) -> &[LiveTailSessionLogEvent]
pub fn session_results(&self) -> &[LiveTailSessionLogEvent]
An array, where each member of the array includes the information for one log event in the Live Tail session.
A sessionResults array can include as many as 500 log events. If the number of log events matching the request exceeds 500 per second, the log events are sampled down to 500 log events to be included in each sessionUpdate structure.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .session_results.is_none().
Sourceimpl LiveTailSessionUpdate
impl LiveTailSessionUpdate
Sourcepub fn builder() -> LiveTailSessionUpdateBuilder
pub fn builder() -> LiveTailSessionUpdateBuilder
Creates a new builder-style object to manufacture LiveTailSessionUpdate.