#[non_exhaustive]pub struct LogFieldType {
pub type: Option<String>,
pub element: Option<Box<LogFieldType>>,
pub fields: Option<Vec<LogFieldsListItem>>,
}Expand description
Defines the data type structure for a log field, including the type, element information, and nested fields for complex types.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<String>The data type of the log field.
element: Option<Box<LogFieldType>>For array or collection types, specifies the element type information.
fields: Option<Vec<LogFieldsListItem>>For complex types, contains the nested field definitions.
Implementations
Sourceimpl LogFieldType
impl LogFieldType
Sourcepub fn element(&self) -> Option<&LogFieldType>
pub fn element(&self) -> Option<&LogFieldType>
For array or collection types, specifies the element type information.
Sourcepub fn fields(&self) -> &[LogFieldsListItem]
pub fn fields(&self) -> &[LogFieldsListItem]
For complex types, contains the nested field definitions.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .fields.is_none().
Sourceimpl LogFieldType
impl LogFieldType
Sourcepub fn builder() -> LogFieldTypeBuilder
pub fn builder() -> LogFieldTypeBuilder
Creates a new builder-style object to manufacture LogFieldType.