#[non_exhaustive]pub struct LogGroup {Show 13 fields
pub log_group_name: Option<String>,
pub creation_time: Option<i64>,
pub retention_in_days: Option<i32>,
pub metric_filter_count: Option<i32>,
pub arn: Option<String>,
pub stored_bytes: Option<i64>,
pub kms_key_id: Option<String>,
pub data_protection_status: Option<DataProtectionStatus>,
pub inherited_properties: Option<Vec<InheritedProperty>>,
pub log_group_class: Option<LogGroupClass>,
pub log_group_arn: Option<String>,
pub deletion_protection_enabled: Option<bool>,
pub bearer_token_authentication_enabled: Option<bool>,
}Expand description
Represents a log group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_group_name: Option<String>The name of the log group.
creation_time: Option<i64>The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
retention_in_days: Option<i32>The number of days to retain the log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1096, 1827, 2192, 2557, 2922, 3288, and 3653.
To set a log group so that its log events do not expire, use DeleteRetentionPolicy.
metric_filter_count: Option<i32>The number of metric filters.
arn: Option<String>The Amazon Resource Name (ARN) of the log group. This version of the ARN includes a trailing :* after the log group name.
Use this version to refer to the ARN in IAM policies when specifying permissions for most API actions. The exception is when specifying permissions for TagResource, UntagResource, and ListTagsForResource. The permissions for those three actions require the ARN version that doesn't include a trailing :*.
stored_bytes: Option<i64>The number of bytes stored.
kms_key_id: Option<String>The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data.
data_protection_status: Option<DataProtectionStatus>Displays whether this log group has a protection policy, or whether it had one in the past. For more information, see PutDataProtectionPolicy.
inherited_properties: Option<Vec<InheritedProperty>>Displays all the properties that this log group has inherited from account-level settings.
log_group_class: Option<LogGroupClass>This specifies the log group class for this log group. There are three classes:
-
The
Standardlog class supports all CloudWatch Logs features. -
The
Infrequent Accesslog class supports a subset of CloudWatch Logs features and incurs lower costs. -
Use the
Deliverylog class only for delivering Lambda logs to store in Amazon S3 or Amazon Data Firehose. Log events in log groups in the Delivery class are kept in CloudWatch Logs for only one day. This log class doesn't offer rich CloudWatch Logs capabilities such as CloudWatch Logs Insights queries.
For details about the features supported by the Standard and Infrequent Access classes, see Log classes
log_group_arn: Option<String>The Amazon Resource Name (ARN) of the log group. This version of the ARN doesn't include a trailing :* after the log group name.
Use this version to refer to the ARN in the following situations:
-
In the
logGroupIdentifierinput field in many CloudWatch Logs APIs. -
In the
resourceArnfield in tagging APIs -
In IAM policies, when specifying permissions for TagResource, UntagResource, and ListTagsForResource.
deletion_protection_enabled: Option<bool>Indicates whether deletion protection is enabled for this log group. When enabled, deletion protection blocks all deletion operations until it is explicitly disabled.
bearer_token_authentication_enabled: Option<bool>Indicates whether bearer token authentication is enabled for this log group. When enabled, bearer token authentication is allowed on operations until it is explicitly disabled.
Implementations
Sourceimpl LogGroup
impl LogGroup
Sourcepub fn log_group_name(&self) -> Option<&str>
pub fn log_group_name(&self) -> Option<&str>
The name of the log group.
Sourcepub fn creation_time(&self) -> Option<i64>
pub fn creation_time(&self) -> Option<i64>
The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn retention_in_days(&self) -> Option<i32>
pub fn retention_in_days(&self) -> Option<i32>
The number of days to retain the log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1096, 1827, 2192, 2557, 2922, 3288, and 3653.
To set a log group so that its log events do not expire, use DeleteRetentionPolicy.
Sourcepub fn metric_filter_count(&self) -> Option<i32>
pub fn metric_filter_count(&self) -> Option<i32>
The number of metric filters.
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the log group. This version of the ARN includes a trailing :* after the log group name.
Use this version to refer to the ARN in IAM policies when specifying permissions for most API actions. The exception is when specifying permissions for TagResource, UntagResource, and ListTagsForResource. The permissions for those three actions require the ARN version that doesn't include a trailing :*.
Sourcepub fn stored_bytes(&self) -> Option<i64>
pub fn stored_bytes(&self) -> Option<i64>
The number of bytes stored.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data.
Sourcepub fn data_protection_status(&self) -> Option<&DataProtectionStatus>
pub fn data_protection_status(&self) -> Option<&DataProtectionStatus>
Displays whether this log group has a protection policy, or whether it had one in the past. For more information, see PutDataProtectionPolicy.
Sourcepub fn inherited_properties(&self) -> &[InheritedProperty]
pub fn inherited_properties(&self) -> &[InheritedProperty]
Displays all the properties that this log group has inherited from account-level settings.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .inherited_properties.is_none().
Sourcepub fn log_group_class(&self) -> Option<&LogGroupClass>
pub fn log_group_class(&self) -> Option<&LogGroupClass>
This specifies the log group class for this log group. There are three classes:
-
The
Standardlog class supports all CloudWatch Logs features. -
The
Infrequent Accesslog class supports a subset of CloudWatch Logs features and incurs lower costs. -
Use the
Deliverylog class only for delivering Lambda logs to store in Amazon S3 or Amazon Data Firehose. Log events in log groups in the Delivery class are kept in CloudWatch Logs for only one day. This log class doesn't offer rich CloudWatch Logs capabilities such as CloudWatch Logs Insights queries.
For details about the features supported by the Standard and Infrequent Access classes, see Log classes
Sourcepub fn log_group_arn(&self) -> Option<&str>
pub fn log_group_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the log group. This version of the ARN doesn't include a trailing :* after the log group name.
Use this version to refer to the ARN in the following situations:
-
In the
logGroupIdentifierinput field in many CloudWatch Logs APIs. -
In the
resourceArnfield in tagging APIs -
In IAM policies, when specifying permissions for TagResource, UntagResource, and ListTagsForResource.
Sourcepub fn deletion_protection_enabled(&self) -> Option<bool>
pub fn deletion_protection_enabled(&self) -> Option<bool>
Indicates whether deletion protection is enabled for this log group. When enabled, deletion protection blocks all deletion operations until it is explicitly disabled.
Sourcepub fn bearer_token_authentication_enabled(&self) -> Option<bool>
pub fn bearer_token_authentication_enabled(&self) -> Option<bool>
Indicates whether bearer token authentication is enabled for this log group. When enabled, bearer token authentication is allowed on operations until it is explicitly disabled.