#[non_exhaustive]pub struct LogStream {
pub log_stream_name: Option<String>,
pub creation_time: Option<i64>,
pub first_event_timestamp: Option<i64>,
pub last_event_timestamp: Option<i64>,
pub last_ingestion_time: Option<i64>,
pub upload_sequence_token: Option<String>,
pub arn: Option<String>,
pub stored_bytes: Option<i64>,
}Expand description
Represents a log stream, which is a sequence of log events from a single emitter of logs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_stream_name: Option<String>The name of the log stream.
creation_time: Option<i64>The creation time of the stream, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
first_event_timestamp: Option<i64>The time of the first event, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
last_event_timestamp: Option<i64>The time of the most recent log event in the log stream in CloudWatch Logs. This number is expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. The lastEventTime value updates on an eventual consistency basis. It typically updates in less than an hour from ingestion, but in rare situations might take longer.
last_ingestion_time: Option<i64>The ingestion time, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC The lastIngestionTime value updates on an eventual consistency basis. It typically updates in less than an hour after ingestion, but in rare situations might take longer.
upload_sequence_token: Option<String>The sequence token.
The sequence token is now ignored in PutLogEvents actions. PutLogEvents actions are always accepted regardless of receiving an invalid sequence token. You don't need to obtain uploadSequenceToken to use a PutLogEvents action.
arn: Option<String>The Amazon Resource Name (ARN) of the log stream.
stored_bytes: Option<i64>Starting on June 17, 2019, this parameter will be deprecated for log streams, and will be reported as zero. This change applies only to log streams. The storedBytes parameter for log groups is not affected.
The number of bytes stored.
Important: As of June 17, 2019, this parameter is no longer supported for log streams, and is always reported as zero. This change applies only to log streams. The storedBytes parameter for log groups is not affected.
Implementations
Sourceimpl LogStream
impl LogStream
Sourcepub fn log_stream_name(&self) -> Option<&str>
pub fn log_stream_name(&self) -> Option<&str>
The name of the log stream.
Sourcepub fn creation_time(&self) -> Option<i64>
pub fn creation_time(&self) -> Option<i64>
The creation time of the stream, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn first_event_timestamp(&self) -> Option<i64>
pub fn first_event_timestamp(&self) -> Option<i64>
The time of the first event, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn last_event_timestamp(&self) -> Option<i64>
pub fn last_event_timestamp(&self) -> Option<i64>
The time of the most recent log event in the log stream in CloudWatch Logs. This number is expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. The lastEventTime value updates on an eventual consistency basis. It typically updates in less than an hour from ingestion, but in rare situations might take longer.
Sourcepub fn last_ingestion_time(&self) -> Option<i64>
pub fn last_ingestion_time(&self) -> Option<i64>
The ingestion time, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC The lastIngestionTime value updates on an eventual consistency basis. It typically updates in less than an hour after ingestion, but in rare situations might take longer.
Sourcepub fn upload_sequence_token(&self) -> Option<&str>
pub fn upload_sequence_token(&self) -> Option<&str>
The sequence token.
The sequence token is now ignored in PutLogEvents actions. PutLogEvents actions are always accepted regardless of receiving an invalid sequence token. You don't need to obtain uploadSequenceToken to use a PutLogEvents action.
Sourcepub fn stored_bytes(&self) -> Option<i64>
👎Deprecated: Starting on June 17, 2019, this parameter will be deprecated for log streams, and will be reported as zero. This change applies only to log streams. The storedBytes parameter for log groups is not affected.
pub fn stored_bytes(&self) -> Option<i64>
Starting on June 17, 2019, this parameter will be deprecated for log streams, and will be reported as zero. This change applies only to log streams. The storedBytes parameter for log groups is not affected.
The number of bytes stored.
Important: As of June 17, 2019, this parameter is no longer supported for log streams, and is always reported as zero. This change applies only to log streams. The storedBytes parameter for log groups is not affected.