#[non_exhaustive]pub struct LookupTable {
pub lookup_table_arn: Option<String>,
pub lookup_table_name: Option<String>,
pub description: Option<String>,
pub table_fields: Option<Vec<String>>,
pub records_count: Option<i64>,
pub size_bytes: Option<i64>,
pub last_updated_time: Option<i64>,
pub kms_key_id: Option<String>,
}Expand description
Contains metadata about a lookup table returned by DescribeLookupTables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lookup_table_arn: Option<String>The ARN of the lookup table.
lookup_table_name: Option<String>The name of the lookup table.
description: Option<String>The description of the lookup table.
table_fields: Option<Vec<String>>The column headers from the first row of the CSV file.
records_count: Option<i64>The number of data rows in the lookup table, excluding the header row.
size_bytes: Option<i64>The size of the lookup table in bytes.
last_updated_time: Option<i64>The time when the lookup table was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
kms_key_id: Option<String>The ARN of the KMS key used to encrypt the lookup table data, if applicable.
Implementations
Sourceimpl LookupTable
impl LookupTable
Sourcepub fn lookup_table_arn(&self) -> Option<&str>
pub fn lookup_table_arn(&self) -> Option<&str>
The ARN of the lookup table.
Sourcepub fn lookup_table_name(&self) -> Option<&str>
pub fn lookup_table_name(&self) -> Option<&str>
The name of the lookup table.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the lookup table.
Sourcepub fn table_fields(&self) -> &[String]
pub fn table_fields(&self) -> &[String]
The column headers from the first row of the CSV file.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .table_fields.is_none().
Sourcepub fn records_count(&self) -> Option<i64>
pub fn records_count(&self) -> Option<i64>
The number of data rows in the lookup table, excluding the header row.
Sourcepub fn size_bytes(&self) -> Option<i64>
pub fn size_bytes(&self) -> Option<i64>
The size of the lookup table in bytes.
Sourcepub fn last_updated_time(&self) -> Option<i64>
pub fn last_updated_time(&self) -> Option<i64>
The time when the lookup table was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ARN of the KMS key used to encrypt the lookup table data, if applicable.
Sourceimpl LookupTable
impl LookupTable
Sourcepub fn builder() -> LookupTableBuilder
pub fn builder() -> LookupTableBuilder
Creates a new builder-style object to manufacture LookupTable.