#[non_exhaustive]pub struct QueryInfo {
pub query_language: Option<QueryLanguage>,
pub query_id: Option<String>,
pub query_string: Option<String>,
pub status: Option<QueryStatus>,
pub create_time: Option<i64>,
pub log_group_name: Option<String>,
pub query_duration: Option<i64>,
pub bytes_scanned: Option<f64>,
pub user_identity: Option<String>,
}Expand description
Information about one CloudWatch Logs Insights query that matches the request in a DescribeQueries operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_language: Option<QueryLanguage>The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
query_id: Option<String>The unique ID number of this query.
query_string: Option<String>The query string used in this query.
status: Option<QueryStatus>The status of this query. Possible values are Cancelled, Complete, Failed, Running, Scheduled, and Unknown.
create_time: Option<i64>The date and time that this query was created.
log_group_name: Option<String>The name of the log group scanned by this query.
query_duration: Option<i64>The duration in milliseconds that the query took to execute.
bytes_scanned: Option<f64>The total number of bytes scanned by the query. This indicates the cost associated with the query.
user_identity: Option<String>The ARN of the user who ran the query.
Implementations
Sourceimpl QueryInfo
impl QueryInfo
Sourcepub fn query_language(&self) -> Option<&QueryLanguage>
pub fn query_language(&self) -> Option<&QueryLanguage>
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
Sourcepub fn query_string(&self) -> Option<&str>
pub fn query_string(&self) -> Option<&str>
The query string used in this query.
Sourcepub fn status(&self) -> Option<&QueryStatus>
pub fn status(&self) -> Option<&QueryStatus>
The status of this query. Possible values are Cancelled, Complete, Failed, Running, Scheduled, and Unknown.
Sourcepub fn create_time(&self) -> Option<i64>
pub fn create_time(&self) -> Option<i64>
The date and time that this query was created.
Sourcepub fn log_group_name(&self) -> Option<&str>
pub fn log_group_name(&self) -> Option<&str>
The name of the log group scanned by this query.
Sourcepub fn query_duration(&self) -> Option<i64>
pub fn query_duration(&self) -> Option<i64>
The duration in milliseconds that the query took to execute.
Sourcepub fn bytes_scanned(&self) -> Option<f64>
pub fn bytes_scanned(&self) -> Option<f64>
The total number of bytes scanned by the query. This indicates the cost associated with the query.
Sourcepub fn user_identity(&self) -> Option<&str>
pub fn user_identity(&self) -> Option<&str>
The ARN of the user who ran the query.