#[non_exhaustive]pub struct QueryParameter {
pub name: String,
pub default_value: Option<String>,
pub description: Option<String>,
}Expand description
This structure defines a query parameter for a saved CloudWatch Logs Insights query definition. Query parameters are supported only for Logs Insights QL queries. They are placeholder variables that you can reference in a query string using the {{parameterName}} syntax. Each parameter can include a default value and a description.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the query parameter. A query parameter name must start with a letter or underscore, and contain only letters, digits, and underscores.
default_value: Option<String>The default value to use for this query parameter if no value is supplied at execution time.
description: Option<String>A description of the query parameter that explains its purpose or expected values.
Implementations
Sourceimpl QueryParameter
impl QueryParameter
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
The name of the query parameter. A query parameter name must start with a letter or underscore, and contain only letters, digits, and underscores.
Sourcepub fn default_value(&self) -> Option<&str>
pub fn default_value(&self) -> Option<&str>
The default value to use for this query parameter if no value is supplied at execution time.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the query parameter that explains its purpose or expected values.
Sourceimpl QueryParameter
impl QueryParameter
Sourcepub fn builder() -> QueryParameterBuilder
pub fn builder() -> QueryParameterBuilder
Creates a new builder-style object to manufacture QueryParameter.