#[non_exhaustive]pub struct RejectedEntityInfo {
pub error_type: EntityRejectionErrorType,
}Expand description
If an entity is rejected when a PutLogEvents request was made, this includes details about the reason for the rejection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_type: EntityRejectionErrorTypeThe type of error that caused the rejection of the entity when calling PutLogEvents.
Implementations
Sourceimpl RejectedEntityInfo
impl RejectedEntityInfo
Sourcepub fn error_type(&self) -> &EntityRejectionErrorType
pub fn error_type(&self) -> &EntityRejectionErrorType
The type of error that caused the rejection of the entity when calling PutLogEvents.
Sourceimpl RejectedEntityInfo
impl RejectedEntityInfo
Sourcepub fn builder() -> RejectedEntityInfoBuilder
pub fn builder() -> RejectedEntityInfoBuilder
Creates a new builder-style object to manufacture RejectedEntityInfo.