#[non_exhaustive]pub struct RejectedLogEventsInfo {
pub too_new_log_event_start_index: Option<i32>,
pub too_old_log_event_end_index: Option<i32>,
pub expired_log_event_end_index: Option<i32>,
}Expand description
Represents the rejected events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.too_new_log_event_start_index: Option<i32>The index of the first log event that is too new. This field is inclusive.
too_old_log_event_end_index: Option<i32>The index of the last log event that is too old. This field is exclusive.
expired_log_event_end_index: Option<i32>The expired log events.
Implementations
Sourceimpl RejectedLogEventsInfo
impl RejectedLogEventsInfo
Sourcepub fn too_new_log_event_start_index(&self) -> Option<i32>
pub fn too_new_log_event_start_index(&self) -> Option<i32>
The index of the first log event that is too new. This field is inclusive.
Sourcepub fn too_old_log_event_end_index(&self) -> Option<i32>
pub fn too_old_log_event_end_index(&self) -> Option<i32>
The index of the last log event that is too old. This field is exclusive.
Sourcepub fn expired_log_event_end_index(&self) -> Option<i32>
pub fn expired_log_event_end_index(&self) -> Option<i32>
The expired log events.
Sourceimpl RejectedLogEventsInfo
impl RejectedLogEventsInfo
Sourcepub fn builder() -> RejectedLogEventsInfoBuilder
pub fn builder() -> RejectedLogEventsInfoBuilder
Creates a new builder-style object to manufacture RejectedLogEventsInfo.