#[non_exhaustive]pub struct ResourcePolicy {
pub policy_name: Option<String>,
pub policy_document: Option<String>,
pub last_updated_time: Option<i64>,
pub policy_scope: Option<PolicyScope>,
pub resource_arn: Option<String>,
pub revision_id: Option<String>,
}Expand description
A policy enabling one or more entities to put logs to a log group in this account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_name: Option<String>The name of the resource policy.
policy_document: Option<String>The details of the policy.
last_updated_time: Option<i64>Timestamp showing when this policy was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
policy_scope: Option<PolicyScope>Specifies scope of the resource policy. Valid values are ACCOUNT or RESOURCE.
resource_arn: Option<String>The ARN of the CloudWatch Logs resource to which the resource policy is attached. Only populated for resource-scoped policies.
revision_id: Option<String>The revision ID of the resource policy. Only populated for resource-scoped policies.
Implementations
Sourceimpl ResourcePolicy
impl ResourcePolicy
Sourcepub fn policy_name(&self) -> Option<&str>
pub fn policy_name(&self) -> Option<&str>
The name of the resource policy.
Sourcepub fn policy_document(&self) -> Option<&str>
pub fn policy_document(&self) -> Option<&str>
The details of the policy.
Sourcepub fn last_updated_time(&self) -> Option<i64>
pub fn last_updated_time(&self) -> Option<i64>
Timestamp showing when this policy was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourcepub fn policy_scope(&self) -> Option<&PolicyScope>
pub fn policy_scope(&self) -> Option<&PolicyScope>
Specifies scope of the resource policy. Valid values are ACCOUNT or RESOURCE.
Sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
The ARN of the CloudWatch Logs resource to which the resource policy is attached. Only populated for resource-scoped policies.
Sourcepub fn revision_id(&self) -> Option<&str>
pub fn revision_id(&self) -> Option<&str>
The revision ID of the resource policy. Only populated for resource-scoped policies.
Sourceimpl ResourcePolicy
impl ResourcePolicy
Sourcepub fn builder() -> ResourcePolicyBuilder
pub fn builder() -> ResourcePolicyBuilder
Creates a new builder-style object to manufacture ResourcePolicy.