#[non_exhaustive]pub struct S3TableIntegrationSource {
pub identifier: Option<String>,
pub data_source: Option<DataSource>,
pub status: Option<S3TableIntegrationSourceStatus>,
pub status_reason: Option<String>,
pub created_time_stamp: Option<i64>,
pub parent_source_identifier: Option<String>,
}Expand description
Represents a data source association with an S3 Table Integration, including its status and metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: Option<String>The unique identifier for this data source association.
data_source: Option<DataSource>The data source associated with the S3 Table Integration.
status: Option<S3TableIntegrationSourceStatus>The current status of the data source association.
status_reason: Option<String>Additional information about the status of the data source association.
created_time_stamp: Option<i64>The timestamp when the data source association was created.
parent_source_identifier: Option<String>The identifier of the parent data source for this association.
Implementations
Sourceimpl S3TableIntegrationSource
impl S3TableIntegrationSource
Sourcepub fn identifier(&self) -> Option<&str>
pub fn identifier(&self) -> Option<&str>
The unique identifier for this data source association.
Sourcepub fn data_source(&self) -> Option<&DataSource>
pub fn data_source(&self) -> Option<&DataSource>
The data source associated with the S3 Table Integration.
Sourcepub fn status(&self) -> Option<&S3TableIntegrationSourceStatus>
pub fn status(&self) -> Option<&S3TableIntegrationSourceStatus>
The current status of the data source association.
Sourcepub fn status_reason(&self) -> Option<&str>
pub fn status_reason(&self) -> Option<&str>
Additional information about the status of the data source association.
Sourcepub fn created_time_stamp(&self) -> Option<i64>
pub fn created_time_stamp(&self) -> Option<i64>
The timestamp when the data source association was created.
Sourcepub fn parent_source_identifier(&self) -> Option<&str>
pub fn parent_source_identifier(&self) -> Option<&str>
The identifier of the parent data source for this association.
Sourceimpl S3TableIntegrationSource
impl S3TableIntegrationSource
Sourcepub fn builder() -> S3TableIntegrationSourceBuilder
pub fn builder() -> S3TableIntegrationSourceBuilder
Creates a new builder-style object to manufacture S3TableIntegrationSource.