#[non_exhaustive]pub struct ScheduledQueryDestination {
pub destination_type: Option<ScheduledQueryDestinationType>,
pub destination_identifier: Option<String>,
pub status: Option<ActionStatus>,
pub processed_identifier: Option<String>,
pub error_message: Option<String>,
}Expand description
Information about a destination where scheduled query results are processed, including processing status and any error messages.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination_type: Option<ScheduledQueryDestinationType>The type of destination for query results.
destination_identifier: Option<String>The identifier for the destination where results are delivered.
status: Option<ActionStatus>The processing status of the destination delivery.
processed_identifier: Option<String>The identifier of the processed result at the destination.
error_message: Option<String>Error message if destination processing failed.
Implementations
Sourceimpl ScheduledQueryDestination
impl ScheduledQueryDestination
Sourcepub fn destination_type(&self) -> Option<&ScheduledQueryDestinationType>
pub fn destination_type(&self) -> Option<&ScheduledQueryDestinationType>
The type of destination for query results.
Sourcepub fn destination_identifier(&self) -> Option<&str>
pub fn destination_identifier(&self) -> Option<&str>
The identifier for the destination where results are delivered.
Sourcepub fn status(&self) -> Option<&ActionStatus>
pub fn status(&self) -> Option<&ActionStatus>
The processing status of the destination delivery.
Sourcepub fn processed_identifier(&self) -> Option<&str>
pub fn processed_identifier(&self) -> Option<&str>
The identifier of the processed result at the destination.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
Error message if destination processing failed.
Sourceimpl ScheduledQueryDestination
impl ScheduledQueryDestination
Sourcepub fn builder() -> ScheduledQueryDestinationBuilder
pub fn builder() -> ScheduledQueryDestinationBuilder
Creates a new builder-style object to manufacture ScheduledQueryDestination.