#[non_exhaustive]pub struct SearchedLogStream {
pub log_stream_name: Option<String>,
pub searched_completely: Option<bool>,
}Expand description
Represents the search status of a log stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_stream_name: Option<String>The name of the log stream.
searched_completely: Option<bool>Indicates whether all the events in this log stream were searched.
Implementations
Sourceimpl SearchedLogStream
impl SearchedLogStream
Sourcepub fn log_stream_name(&self) -> Option<&str>
pub fn log_stream_name(&self) -> Option<&str>
The name of the log stream.
Sourcepub fn searched_completely(&self) -> Option<bool>
pub fn searched_completely(&self) -> Option<bool>
Indicates whether all the events in this log stream were searched.
Sourceimpl SearchedLogStream
impl SearchedLogStream
Sourcepub fn builder() -> SearchedLogStreamBuilder
pub fn builder() -> SearchedLogStreamBuilder
Creates a new builder-style object to manufacture SearchedLogStream.