#[non_exhaustive]pub struct SyslogConfiguration {
pub log_group_arn: Option<String>,
pub source_type: Option<SyslogSourceType>,
pub vpc_endpoint_id: Option<String>,
pub created_at: Option<i64>,
}Expand description
Contains information about a syslog configuration associated with a log group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.log_group_arn: Option<String>The ARN of the log group associated with this syslog configuration.
source_type: Option<SyslogSourceType>The source type for the syslog configuration.
vpc_endpoint_id: Option<String>The ID of the VPC endpoint used for syslog ingestion.
created_at: Option<i64>The time when the syslog configuration was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Implementations
Sourceimpl SyslogConfiguration
impl SyslogConfiguration
Sourcepub fn log_group_arn(&self) -> Option<&str>
pub fn log_group_arn(&self) -> Option<&str>
The ARN of the log group associated with this syslog configuration.
Sourcepub fn source_type(&self) -> Option<&SyslogSourceType>
pub fn source_type(&self) -> Option<&SyslogSourceType>
The source type for the syslog configuration.
Sourcepub fn vpc_endpoint_id(&self) -> Option<&str>
pub fn vpc_endpoint_id(&self) -> Option<&str>
The ID of the VPC endpoint used for syslog ingestion.
Sourcepub fn created_at(&self) -> Option<i64>
pub fn created_at(&self) -> Option<i64>
The time when the syslog configuration was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Sourceimpl SyslogConfiguration
impl SyslogConfiguration
Sourcepub fn builder() -> SyslogConfigurationBuilder
pub fn builder() -> SyslogConfigurationBuilder
Creates a new builder-style object to manufacture SyslogConfiguration.