#[non_exhaustive]pub struct DeliverySourceConfigurationSchemaBuilder { /* private fields */ }Expand description
A builder for DeliverySourceConfigurationSchema.
Implementations
Sourceimpl DeliverySourceConfigurationSchemaBuilder
impl DeliverySourceConfigurationSchemaBuilder
Sourcepub fn key_name(self, input: impl Into<String>) -> Self
pub fn key_name(self, input: impl Into<String>) -> Self
The name of the configuration.
This field is required.Sourcepub fn set_key_name(self, input: Option<String>) -> Self
pub fn set_key_name(self, input: Option<String>) -> Self
The name of the configuration.
Sourcepub fn get_key_name(&self) -> &Option<String>
pub fn get_key_name(&self) -> &Option<String>
The name of the configuration.
Sourcepub fn value_type(
self,
input: DeliverySourceConfigurationSchemaValueType,
) -> Self
pub fn value_type( self, input: DeliverySourceConfigurationSchemaValueType, ) -> Self
The data type of the configuration value. Valid values are string, boolean, int, double, and long.
Sourcepub fn set_value_type(
self,
input: Option<DeliverySourceConfigurationSchemaValueType>,
) -> Self
pub fn set_value_type( self, input: Option<DeliverySourceConfigurationSchemaValueType>, ) -> Self
The data type of the configuration value. Valid values are string, boolean, int, double, and long.
Sourcepub fn get_value_type(
&self,
) -> &Option<DeliverySourceConfigurationSchemaValueType>
pub fn get_value_type( &self, ) -> &Option<DeliverySourceConfigurationSchemaValueType>
The data type of the configuration value. Valid values are string, boolean, int, double, and long.
Sourcepub fn default_value(self, input: impl Into<String>) -> Self
pub fn default_value(self, input: impl Into<String>) -> Self
The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.
This field is required.Sourcepub fn set_default_value(self, input: Option<String>) -> Self
pub fn set_default_value(self, input: Option<String>) -> Self
The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.
Sourcepub fn get_default_value(&self) -> &Option<String>
pub fn get_default_value(&self) -> &Option<String>
The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.
Sourcepub fn supported_values(self, input: impl Into<String>) -> Self
pub fn supported_values(self, input: impl Into<String>) -> Self
Appends an item to supported_values.
To override the contents of this collection use set_supported_values.
The list of allowed values for the configuration. Empty for free-form configuration.
Sourcepub fn set_supported_values(self, input: Option<Vec<String>>) -> Self
pub fn set_supported_values(self, input: Option<Vec<String>>) -> Self
The list of allowed values for the configuration. Empty for free-form configuration.
Sourcepub fn get_supported_values(&self) -> &Option<Vec<String>>
pub fn get_supported_values(&self) -> &Option<Vec<String>>
The list of allowed values for the configuration. Empty for free-form configuration.
Sourcepub fn min_value(self, input: f64) -> Self
pub fn min_value(self, input: f64) -> Self
The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Sourcepub fn set_min_value(self, input: Option<f64>) -> Self
pub fn set_min_value(self, input: Option<f64>) -> Self
The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Sourcepub fn get_min_value(&self) -> &Option<f64>
pub fn get_min_value(&self) -> &Option<f64>
The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Sourcepub fn max_value(self, input: f64) -> Self
pub fn max_value(self, input: f64) -> Self
The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Sourcepub fn set_max_value(self, input: Option<f64>) -> Self
pub fn set_max_value(self, input: Option<f64>) -> Self
The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Sourcepub fn get_max_value(&self) -> &Option<f64>
pub fn get_max_value(&self) -> &Option<f64>
The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.
Sourcepub fn build(self) -> Result<DeliverySourceConfigurationSchema, BuildError>
pub fn build(self) -> Result<DeliverySourceConfigurationSchema, BuildError>
Consumes the builder and constructs a DeliverySourceConfigurationSchema.
This method will fail if any of the following fields are not set: